/*
 * gtkoptions.h
 *
 * by Joern Thyssen <jth@gnubg.org>, 2003
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of version 3 or later of the GNU General Public License as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: gtkoptions.h,v 1.5 2007/09/02 20:27:02 c_anthon Exp $
 */

#ifndef _GTKOPTIONS_H_
#define _GTKOPTIONS_H_

extern void GTKSetOptions( void );
extern void GTKSound(void);

#endif /* _GTKOPTIONS_H_ */
